#!/bin/sh
#   Copyright (c) 2010 digitalSTROM.org, Zurich, Switzerland
#
#   Author: Sergey 'Jin' Bostandzhyan <jin@mediatomb.cc>
#
#   This file is part of digitalSTROM Server.
#
#   netinfo.sh is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   netinfo.sh is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with netinfo.sh. If not, see <http://www.gnu.org/licenses/>.

CONSOLE_MODE=0

if [[ "$1" == "console" ]]; then
    CONSOLE_MODE=1
fi

if [[ "$CONSOLE_MODE" -eq "0" ]]; then
    echo "Content-Type: application/json"
    echo ""
fi
# source common functions
. ./errlib.sh
. ./netlib.sh
. ./jsonlib.sh

INTERFACE_FILE="/etc/network/interfaces"

# json_netinfo mode ip netmask gateway dns1 dns2
json_netinfo() {
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        echo -n "{ \"success\": true, \"code\": $ERR_OK, \"message\": \"OK\", "
        echo -n "\"data\": { "
        echo -n "\"mode\": \"$1\",  \"ip\": \"$2\", \"netmask\": \"$3\", "
        echo -n "\"gateway\": \"$4\", \"dns1\": \"$5\", \"dns2\": \"$6\" }"
        echo    " }"
    else
        echo "$1:$2:$3:$4:$5:$6"
    fi
}

if [[ ! -f $INTERFACE_FILE ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MODE "Could not determine network settings!"
    fi
    exit 1
fi

NETMODE=`grep "iface eth0 inet" $INTERFACE_FILE | cut -d " " -f 4`
if [[ -z "$NETMODE" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MODE "Could not determine network settings!"
    fi
    exit 1
fi

if [[ "$NETMODE" != "dhcp" ]] && [[ "$NETMODE" != "static" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MODE "Failed to determine network mode (dhcp/static ip)!"
    fi
    exit 1
fi

NETMASK=`ifconfig eth0 | grep 'inet addr:' | cut -d: -f4`
if [[ -z "$NETMASK" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MASK "Failed to determine netmask!"
    fi
    exit 1
fi

validate_ip $NETMASK
if [[ "$?" -ne "0" ]]; then    
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_MASK "Invalid netmask detected!"
    fi
    exit 1
fi

IP=`ifconfig eth0 | grep 'inet addr:' | cut -d: -f2 | cut -d " " -f1`
if [[ -z "$IP" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_IP "Failed to determine ip address!"
    fi
    exit 1
fi

validate_ip $IP
if [[ "$?" -ne "0" ]]; then
    if [[ "$CONSOLE_MODE" -eq "0" ]]; then
        json_error $ERR_IP "Invalid ip address detected!"
    fi
    exit 1
fi

# gateway is optional, but should make sense if present
GATEWAY=`route -n | grep UG | grep eth0 | awk '{ print $2}'`
if [[ -n "$GATEWAY" ]]; then
    validate_ip $GATEWAY
    if [[ "$?" -ne "0" ]]; then
        if [[ "$CONSOLE_MODE" -eq "0" ]]; then
            json_error $ERR_GW "Invalid gateway address detected!"
        fi
        exit 1
    fi
fi

DNS1=
DNS2=

if [[ -f "/etc/resolv.conf" ]]; then
    for line in `cat /etc/resolv.conf`; do
        if [[ -n "$line" ]]; then
            DNS=`echo $line | cut -d " " -f 2`

            if [[ -z "$DNS" ]]; then
                continue
            fi

            validate_ip $DNS
            if [[ "$?" -ne "0" ]]; then
                continue
            fi
            if [[ -z "$DNS1" ]]; then
                DNS1=$DNS
                continue
            fi
            if [[ -z "$DNS2" ]]; then
                DNS2=$DNS
                break
            fi
        else
            continue 
        fi
    done
fi

json_netinfo "$NETMODE" "$IP" "$NETMASK" "$GATEWAY" "$DNS1" "$DNS2"

