Ext.namespace('dSS11', 'dSS11.config');

dSS11.SysConfigPanel = Ext.extend(Ext.Panel,
    {
        initComponent: function()
        {

            this.sysName = new Ext.form.FieldSet(
                {
                    layout: 'form',
                    title:  _("Installation name"),
                    scope:  this,
                    items:  [
                        new Ext.Panel({
                            autoEl: 'span',
                            cls: 'x-green-text',
                            autoLoad: dSS11.config.langPath + 'nameconf.text',
                            bodyBorder: false,
                            footer: true,
                            footerCfg: { html: '<br/>' } 
                        }),
                        {
                            layout: 'column',
                            bodyBorder: false,
                            items: [
                                {
                                    layout: 'form',
                                    bodyBorder: false,
                                    width: 435,
                                    items: [
                                        {
                                            xtype: 'textfield',
                                            width: 320,
                                            name: 'hostname',
                                            allowBlank: false,
                                            fieldLabel: _("Name"),
                                            maxLength: 64,
                                            validator: this.validateHostName
                                        }
                                    ]
                                }, 
                                {
                                    bodyBorder: false,
                                    items: [
                                        {
                                            xtype: 'button',
                                            text: _("Apply"),
                                            handler: this.setSystemName.createDelegate(this)
                                        }
                                    ]
                                }
                            ] // border panel items
                        } // column panel
                    ] // name field set items 
                } // name field set
            );

            this.nameForm = new Ext.FormPanel(
                {
                    padding: 6,
                    ref: 'nameform',
                    id: 'nameform',
                    scope: this,
                    items: [
                        this.sysName
                    ]
                }
            );

            this.restart = new Ext.form.FieldSet(
                {
                    layout: 'column',
                    title:  _("Restart digitalSTROM server application"),
                    scope:  this,
                    items: [
                        {
                            xtype: 'button',
                            text: _("Restart dSS"),
                            minWidth: 80,
                            handler: this.restartdSS.createDelegate(this)
                        },
                        {
                            xtype:  'panel',
                            padding: 3,
                            hideBorders: true,
                            ref: 'dssUptime',
                            bodyBorder: false,
                            cls: 'x-green-text',
                            autoLoad: '/cgi-bin/dssuptime.hs'
                        }
                    ]
                }
            );

            this.reboot = new Ext.form.FieldSet(
                {
                    layout: 'column',
                    title:  _("Reboot system"),
                    scope:  this,
                    items: [
                        {
                            xtype: 'button',
                            text: _("Reboot"),
                            minWidth: 80,
                            handler: this.reboot.createDelegate(this)
                        },
                        {
                            xtype:  'panel',
                            padding: 3,
                            bodyBorder: false,
                            hideBorders: true,
                            ref: 'Uptime',
                            cls: 'x-green-text',
                            autoLoad: '/cgi-bin/dss11uptime.hs'
                        }
                    ]
                }
            );

            Ext.apply(this, {
                hideBorders: true,
                items: [
                    this.nameForm,
                    {
                        layout: 'column',
                        bodyBorder: false,
                        padding: 3,
                        items: [
                            {
                                columnWidth: .5,
                                padding: 3,
                                xtype: 'panel',
                                bodyBorder: false,
                                items: [ this.restart ]
                            },
                            {
                                columnWidth: .5,
                                padding: 3,
                                xtype: 'panel',
                                bodyBorder: false,
                                items: [ this.reboot ]
                            }
                        ]
                    }
                ]
            });
            
            dSS11.SysConfigPanel.superclass.initComponent.apply(this, arguments);

           this.on('afterrender',
                    function() {
                        this.reloadData.defer(1000, this);
                    },
                    this);

        }, // initcomponent
        restartdSS: function() {
            Ext.Msg.show({
                title: _("Restart dSS application"),
                msg: _("Are you sure that you want to restart the dSS application?"),
                    buttons: Ext.Msg.YESNO,
                    scope: this,
                    fn: function(button, text) {
                        if (button == 'yes') {
                            this.el.mask(_("Restarting dSS application") + 
                                            "...", 'x-mask-loading');

                            Ext.Ajax.request({
                                url: '/cgi-bin/restartdss.sh',
                                disableCaching: true,
                                //params: { 'dss' : 'dss' }, // dummy parameter
                                method: 'GET',
                                scope: this,
                                success: function(action) {
                                    this.el.unmask();
                                    try {
                                        var jsonData = Ext.util.JSON.decode(
                                                action.responseText);

                                        if (jsonData.success != true) {
                                            Ext.Msg.alert(_("Error"), 
                                                            jsonData.message);
                                            return;
                                        } else {
                                            Ext.Msg.show({
                                                title: _("Info"),
                                                msg: _("digitalSTROM " + 
                                                "server application " + 
                                                "successfully restarted"),
                                                icon: Ext.MessageBox.INFO,
                                                buttons: Ext.Msg.OK
                                            });
                                        }
                                    } catch (error) {
                                        Ext.Msg.alert(_("Error"),
                                            _("digitalSTROM server " + 
                                              "application could not be " + 
                                              "restarted") + ": " + 
                                                error.message);
                                    }
                                    this.restart.dssUptime.doAutoLoad();
                                },
                                failure: function(action) {
                                    this.el.unmask();
                                    switch (action.failureType) {
                                        case Ext.form.Action.CONNECT_FAILURE:
                                            Ext.Msg.alert(_("Error"),
                                                _("Ajax communication failed"));
                                        break;
                                        case Ext.form.Action.SERVER_INVALID:
                                        default:
                                        Ext.Msg.alert(_("Error"),
                                            _("digitalSTROM server " + 
                                              "application could not be " + 
                                              "restarted"));
                                        break;
                                    }
                                    this.restart.dssUptime.doAutoLoad();
                                }
                            });

                        }
                    },
                    animEl: 'elId',
                    icon: Ext.MessageBox.QUESTION
            });

        },
        rebootWaitMsg: function(secs, w) {
            if (secs > 0) {
                w.updateProgress(1-(secs/dSS11.config.rebootWait), secs + " " +
                        dSS11.config.gt.ngettext("second remaining", 
                                                 "seconds remaining",
                                                  secs));
                secs--;
                this.rebootWaitMsg.defer(1000, this, [secs, w]);
            } else {
                w.hide();
                this.findParentByType(Ext.Viewport).el.mask(_("Reloading page") + "...");
                var params = Ext.urlDecode(window.location.search.substring(1));
                params.select = 3;
                window.location = window.location.protocol + '//' + 
                                  window.location.hostname + '/?' + 
                                  Ext.urlEncode(params);
            }
        },
        reboot: function() {
            Ext.Msg.show({
                title: _("Reboot system"),
                msg: _("Are you sure that you want to reboot the system?") +
                       "<br/>" +
                       _("Note: this will take about a minute"),
                    buttons: Ext.Msg.YESNO,
                    scope: this,
                    fn: function(button, text) {
                        if (button == 'yes') {
                            Ext.Ajax.request({
                                url: '/cgi-bin/rebootwrapper.sh',
                                disableCaching: true,
                                params: { action : 'reboot' },
                                method: 'GET',
                                scope: this,
                                success: function(action) {
                                    this.el.unmask();
                                    try {
                                        var jsonData = Ext.util.JSON.decode(
                                                action.responseText);

                                        if (jsonData.success != true) {
                                            Ext.Msg.alert(_("Error"), 
                                                            jsonData.message);
                                            return;
                                        } else {
                                            var w = Ext.Msg.progress(
                                                _("Rebooting system"),
                                                _("Please wait while the " +
                                                  "system is rebooting") + 
                                                  "<br/>" + 
                                                _("The setup page will be " +
                                                  "automatically reloaded " +
                                                  "after the time elapses"));
                                            this.rebootWaitMsg(
                                                    dSS11.config.rebootWait, w);
                                        }
                                    } catch (error) {
                                        Ext.Msg.alert(_("Error"),
                                            _("System reboot could not " + 
                                              "be initiated") + ": " + 
                                                error.message);
                                    }
                                },
                                failure: function(action) {
                                    this.el.unmask();
                                    switch (action.failureType) {
                                        case Ext.form.Action.CONNECT_FAILURE:
                                            Ext.Msg.alert(_("Error"),
                                                _("Ajax communication failed"));
                                        break;
                                        case Ext.form.Action.SERVER_INVALID:
                                        default:
                                        Ext.Msg.alert(_("Error"),
                                            _("System reboot could not be " + 
                                              "initiated"));
                                        break;
                                    }
                                }
                            });

                        }
                    },
                    animEl: 'elId',
                    icon: Ext.MessageBox.QUESTION
            });
        },
        setSystemName:  function() {
            if (!this.nameForm.getForm().isValid()) {
                Ext.Msg.alert(_("Error"), _("The name you entered is invalid! Please do not use any whitespaces or special characters."));
                return;
            }

            this.el.mask(_("Applying changes") + '...', 'x-mask-loading');

            this.nameForm.getForm().submit({ 
                url: '/cgi-bin/setnamewrapper.sh',
                method: 'GET',
                scope: this,
                success: function(form, action) {
                    this.el.unmask();
                },
                failure: function(form, action) {
                    this.el.unmask();
                    switch (action.failureType) {
                        case Ext.form.Action.CONNECT_FAILURE:
                            Ext.Msg.alert(_("Error"),
                                _("Ajax communication failed"));
                        break;
                        case Ext.form.Action.SERVER_INVALID:
                        default:
                            Ext.Msg.alert(_("Error"),
                                    _("Could not load installation name"));
                        break;
                    }
                }
            });
        },
        validateHostName: function(name) {
            if ((name.length == 0) || (name.length > 64)) {
                return false;
            }

            var expr = /[^0-9a-zA-Z-]/;
            if (expr.exec(name) === null) {
                return true;
            }

            return false;
        },
        reloadHostName: function() {
            this.nameForm.load({
                url: '/cgi-bin/getname.sh',
                method: 'GET',
                scope: this,
                disableCaching: true,
                waitMsgTarget: this.sysName.el,
                success: function(form, action) {
                    try {
                        var jsonData = Ext.util.JSON.decode(
                                                action.response.responseText);

                        if (jsonData.success != true) {
                            Ext.Msg.alert(_("Error"), jsonData.message);
                            return;
                        }
                    } catch (error) {
                        Ext.Msg.alert(_("Error"),
                            _("Could not load installation name") +
                                ": "  + error.message);
                    }

                },
                failure: function(form, action) {
                    switch (action.failureType) {
                        case Ext.form.Action.CONNECT_FAILURE:
                            Ext.Msg.alert(_("Error"),
                                _("Ajax communication failed"));
                        break;
                        case Ext.form.Action.SERVER_INVALID:
                        default:
                            Ext.Msg.alert(_("Error"),
                                    _("Could not load installation name"));
                        break;
                    }
                }
            });
        },
        reloadData: function() {
            this.reloadHostName();
        }
    }
);

Ext.reg('dss11sysconfig', dSS11.SysConfigPanel);

